from setuptools import setup

setup(name='zyr-distributions',
      version='0.2',
      description='Gaussian and Binomial distributions',
      author = 'Richard',
      author_email = 'izyrichy@gmail.com',
      packages=['zyr-distributions'],
      zip_safe=False)
